#!/usr/bin/env node

const fs = require('fs');

const elv = require('elv');
const Kibbutz = require('kibbutz');
const RcProvider = require('kibbutz-rc');

const { exec } = require('child_process');

const snyk = require('snyk');

/*const defaults = {
  value: {
    snyk: {
      run: true,
    },
    whitesource: {
      run: false,
    },
    sonar: {
      run: true,
    },
  },
};*/

const anxietyConfig = new Kibbutz();

const rcProvider = new RcProvider({
  appName: 'anxiety',
});

const cli = () => {
  anxietyConfig.load([rcProvider], (err, config) => {
    if (elv(err)) {
      throw new Error({
        err: true,
        result: 'No configuration found for anxiety',
      });
    }

    if (elv(config)) {
      if (elv(config.snyk)) {
        if (elv(config.snyk.run) && config.snyk.run) {
          if (!elv(process.env.SNYK_TOKEN)) {
            throw new Error({
              err: true,
              result: 'Could not find SNYK_TOKEN',
            });
          }

          snyk.test('.').then((data) => {
            console.log(data);
            this.emit('error', new Error(`Snyk found vulnerabilities ${JSON.stringify(data.vulnerabilities)}`));
          });
        }
      }

      if (elv(config.whitesource)) {
        if (elv(config.whitesource.run) && config.whitesource.run) {
          if (!elv(process.env.WHITESOURCE_API_KEY)) {
            throw new Error({
              err: true,
              result: 'Could not find WHITESOURCE_API_KEY',
            });
          }

          let whitesource;

          const values = 'includes=**/*.js\r\n';

          fs.writeFile('whitesource-fs-agent.config', values, (err) => {
            if (err) throw err;

            whitesource = exec(`${__dirname}/shell/whitesource.sh ${__dirname}`);

            whitesource.stdout.on('data', (data) => {
              console.log(data);
            });

            whitesource.stderr.on('data', (data) => {
              console.log(data);
            });
          });
        }
      }

      if (elv(config.sonar)) {
        if (elv(config.sonar.run) && config.sonar.run) {
          if (!elv(process.env.SONAR_TOKEN)) {
            throw new Error({
              err: true,
              result: 'Could not find SONAR_TOKEN',
            });
          }

          let sonar;

          const values = 'sonar.sources=src\r\nsonar.projectKey=com.codemouse.sast-demo\r\nsonar.projectName=sast-demo\r\nsonar.projectVersion=1.0.0\r\n';

          fs.writeFile('sonar-project.properties', values, (err) => {
            if (err) throw err;

            sonar = exec(`${__dirname}/shell/sonar.sh ${__dirname}`);

            sonar.stdout.on('data', (data) => {
              console.log(data);
            });

            sonar.stderr.on('data', (data) => {
              console.log(data);
            });
          });
        }
      }

      return {
        err: false,
        result: '',
      };
    }
  });
};

cli(process.argv);
